@@ -1,21 +1,3 @@
-## Copyright 2012-2016 Sebastian Gibb
-## <mail@sebastiangibb.de>
-##
-## This file is part of MALDIquant for R and related languages.
-##
-## MALDIquant is free software: you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published by
-## the Free Software Foundation, either version 3 of the License, or
-## (at your option) any later version.
-##
-## MALDIquant is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU General Public License for more details.
-##
-## You should have received a copy of the GNU General Public License
-## along with MALDIquant. If not, see <http://www.gnu.org/licenses/>
-
 ## binPeaks
 ##  binning peaks by splitting at the largest gap
 ##  This is a wrapper function around .binPeaks which prepares the peak list
@@ -51,7 +33,7 @@ binPeaks <- function(l, method=c("strict", "relaxed"), tolerance=0.002) {
   samples <- rep.int(seq_along(l), lengths(l))
 
   ## sort values by mass
-  s <- sort.int(mass, method="quick", index.return=TRUE)
+  s <- sort.int(mass, index.return=TRUE)
 
   mass <- s$x
   intensities <- intensities[s$ix]
@@ -74,7 +56,7 @@ binPeaks <- function(l, method=c("strict", "relaxed"), tolerance=0.002) {
 
   ## resort mass (order could change if "relaxed" is used)
   if (method == "relaxed") {
-    s <- sort.int(mass, method="quick", index.return=TRUE)
+    s <- sort.int(mass, index.return=TRUE)
     mass <- s$x
     intensities <- intensities[s$ix]
     snr <- snr[s$ix]
